@@ -4,11 +4,11 @@
 // See file LICENSE for details and terms of copying.
 
 #import <objectbase.h>
-#import <simtools/GUISwarm.h>
+#import <simtoolsgui/GUISwarm.h>
 #import "PplModelSwarm.h"
 
 // Sample graphical interface swarm for models.
-@interface PplObserverSwarm : GUISwarm 
+@interface PplObserverSwarm: GUISwarm 
 {
   int displayFrequency;
 
@@ -16,9 +16,9 @@
   id displaySchedule;
 
   // add the modelswarm to the observer swarm
-  PplModelSwarm * pplModelSwarm;
+  PplModelSwarm* pplModelSwarm;
   // add the counter to the observer swarm
-  Counter * observedCounter;
+  Counter* observedCounter;
 }
 
 + createBegin: aZone;
