@@ -3,8 +3,9 @@
 // implied warranty of merchantability or fitness for a particular purpose.
 // See file LICENSE for details and terms of copying.
 
-#import <random.h>
 #import "PplModelSwarm.h"
+#import <objectbase.h>
+#import <random.h>
 
 // Implementation of the model for ppl.
 
@@ -91,7 +92,7 @@
       for (incj = 1; incj <= namesize; incj++)
         {
           temp_char[0] = [uniformIntRand getIntegerWithMin: 'a' withMax: 'z'];
-          [name appendC: (char *) &temp_char];
+          [name catC: (char *) &temp_char];
         }
       
       // the null topic is how undesirable communication is for this person
