@@ -104,15 +104,15 @@ static unsigned numPredictorsToShow = 7;
   
   useHisto = [Histogram createBegin: globalZone];
   SET_WINDOW_GEOMETRY_RECORD_NAME (useHisto);
+  [useHisto setNumBins: numPredictorsToShow];
   useHisto = [useHisto createEnd];
 
   [useHisto enableDestroyNotification: self
             notificationMethod: @selector(_histogramDeath_:)];
 
   [useHisto setWidth: 400 Height: 250];
-  [useHisto setNumPoints: numPredictorsToShow
-	    Labels: pred
-	    Colors: predictorColors];
+  [useHisto setLabels: pred];
+  [useHisto setColors: predictorColors];
   [useHisto setTitle: "Usage of predictors"];
   [useHisto setAxisLabelsX: "predictor index" Y: "usage of predictor"];
   [useHisto pack];
