@@ -11,15 +11,13 @@
  * (Swarm) code taken and retooled to run under Swarm. Quick port, lots
  * of global variables left in.
  */
-#import <defobj.h>
-#import <tkobjc.h>
-#import <simtools.h>
+#import <simtoolsgui.h>
 #import "MarketObserverSwarm.h"
 
 int
-main (int argc, char **argv)
+main (int argc, const char **argv)
 {
-  MarketObserverSwarm * observerSwarm;
+  MarketObserverSwarm *observerSwarm;
   
   initSwarm (argc, argv);
 
