@@ -58,7 +58,7 @@
   return obj;		// We return the newly created ObserverSwarm
 }
 
-- _updateMousetraps_: window
+- _setupMousetraps_: window
 {
   int x, y, size;
   // draw all the mousetraps 
@@ -74,6 +74,9 @@
             if (window)
               [window drawPointX: x Y: y Color: 1];
             [trap setDisplayWidget: window];
+#ifdef SCHEDULE_INSPECTION
+            [trap setScheduleItem: scheduleItem];
+#endif
           }
       }
   return self;
@@ -83,7 +86,7 @@
 {
   [displayWindow drop];
   displayWindow = nil;
-  [self _updateMousetraps_: nil];
+  [self _setupMousetraps_: nil];
   return self;
 }
 
@@ -164,6 +167,20 @@
                          withFeedFrom: [mousetrapModelSwarm getStats] 
                           andSelector: M(getNumBalls)] ;
 
+#ifdef SCHEDULE_INSPECTION
+  // scheduleItem needs to be ready before _setupMousetraps_
+  canvas = [Canvas create: [self getZone]];
+  [canvas setWidth: 350 Height: 400];
+  [canvas setWindowTitle: "Mousetrap Schedule"];
+  [canvas pack];
+
+  scheduleItem = [ScheduleItem createBegin: [self getZone]];
+  [scheduleItem setX: 5 Y: 10];
+  [scheduleItem setCanvas: canvas];
+  scheduleItem = [scheduleItem createEnd];
+#endif
+
+
   // Next, create a 2d window to display the mousetrap world
   // and  set its size, zoom factor, title.
 
@@ -177,7 +194,7 @@
   [displayWindow setWidth: [mousetrapModelSwarm getGridSize]
 		 Height: [mousetrapModelSwarm getGridSize]];
   [displayWindow setWindowTitle: "Mousetrap World"];
-  [self _updateMousetraps_: displayWindow];
+  [self _setupMousetraps_: displayWindow];
   [displayWindow drawSelf];
   [displayWindow pack];
   
@@ -197,7 +214,7 @@
   mousetrapDisplay = [Object2dDisplay createBegin: [self getZone]];
   [mousetrapDisplay setDisplayWidget: displayWindow];
   [mousetrapDisplay setDiscrete2dToDisplay: [mousetrapModelSwarm getWorld]];
-  [mousetrapDisplay setDisplayMessage: M(drawSelfOn:)];   // draw method
+  [mousetrapDisplay setDisplayMessage: M(noMethod:)];
   mousetrapDisplay = [mousetrapDisplay createEnd];
 
   // And tell the displayWindow to send mouse clicks to the mousetrapDisplay
@@ -216,6 +233,9 @@
 {
   if (displayWindow)
     [displayWindow drawSelf];
+#ifdef SCHEDULE_INSPECTION
+  [scheduleItem update];
+#endif
   return self;
 }
 
@@ -238,6 +258,10 @@
   
   [mousetrapModelSwarm buildActions];
 
+#ifdef SCHEDULE_INSPECTION
+  [scheduleItem setSchedule: [mousetrapModelSwarm getSchedule]];
+#endif
+
   // Create an ActionGroup for display: a bunch of things that occur in
   // a specific order, but in the same step of simulation time. Some of 
   // these actions could be executed in parallel, but we don't explicitly
@@ -263,7 +287,7 @@
   // This is crucial: without this, no graphics update and the control
   // panel will be dead. It's best to put it at the end of the display schedule
 
-  [displayActions createActionTo: actionCache        message: M(doTkEvents)];
+  [displayActions createActionTo: actionCache         message: M(doTkEvents)];
 
   // And the display schedule. Note the repeat interval is set from our
   // own Swarm data structure. Display is frequently the slowest part of a
