@@ -9,12 +9,13 @@
 // Swarm, let it build and activate, and set it to running.
 
 int
-main(int argc, char ** argv) {
-  ObserverSwarm * observerSwarm;
+main (int argc, const char **argv)
+{
+  ObserverSwarm *observerSwarm;
 
   // Swarm initialization: all Swarm apps must call this first.
 
-  initSwarm(argc, argv);
+  initSwarm (argc, argv);
 
   // Make the bug model swarm
 
